@@ -1,16 +1,13 @@
 use strict;
 use warnings;
-package Class::Method::Modifiers;
-BEGIN {
-  $Class::Method::Modifiers::AUTHORITY = 'cpan:SARTAK';
-}
-# git description: v2.09-5-gb272828
-$Class::Method::Modifiers::VERSION = '2.10';
+package Class::Method::Modifiers; # git description: v2.13-4-g6e49964
 # ABSTRACT: Provides Moose-like method modifiers
-# vim: set ts=8 sw=4 tw=78 et :
+# KEYWORDS: method wrap modification patch
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-# work around https://rt.cpan.org/Ticket/Display.html?id=89173
-use base ('Exp'.'orter');
+our $VERSION = '2.14';
+
+use base 'Exporter';
 
 our @EXPORT = qw(before after around);
 our @EXPORT_OK = (@EXPORT, qw(fresh install_modifier));
@@ -211,7 +208,9 @@ sub _sub_attrs {
     my ($coderef) = @_;
     local *_sub = $coderef;
     local $@;
-    (eval 'sub { _sub = 1 }') ? ':lvalue' : '';
+    # this assignment will fail to compile if it isn't an lvalue sub.  we
+    # never want to actually call the sub though, so we return early.
+    (eval 'return 1; &_sub = 1') ? ':lvalue' : '';
 }
 
 sub _is_in_package {
@@ -225,18 +224,22 @@ sub _is_in_package {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Class::Method::Modifiers - provides Moose-like method modifiers
+Class::Method::Modifiers - Provides Moose-like method modifiers
 
 =head1 VERSION
 
-version 2.10
+version 2.14
 
 =head1 SYNOPSIS
 
     package Child;
-    use parent 'Parent';
+    use parent 'MyParent';
     use Class::Method::Modifiers;
 
     sub new_method { }
@@ -261,7 +264,6 @@ version 2.10
         warn "freshly added method\n";
     };
 
-
 =head1 DESCRIPTION
 
 =for stopwords CLOS
@@ -277,7 +279,7 @@ C<Class::Method::Modifiers> provides three modifiers: C<before>, C<around>, and
 C<after>. C<before> and C<after> are run just before and after the method they
 modify, but can not really affect that original method. C<around> is run in
 place of the original method, with a hook to easily call that original method.
-See the C<MODIFIERS> section for more details on how the particular modifiers
+See the L</MODIFIERS> section for more details on how the particular modifiers
 work.
 
 One clear benefit of using C<Class::Method::Modifiers> is that you can define
@@ -289,20 +291,27 @@ those methods to flesh out the specifics.
 Parent classes need not know about C<Class::Method::Modifiers>. This means you
 should be able to modify methods in I<any> subclass. See
 L<Term::VT102::ZeroBased> for an example of subclassing with
-C<ClasS::Method::Modifiers>.
+C<Class::Method::Modifiers>.
 
 In short, C<Class::Method::Modifiers> solves the problem of making sure you
 call C<< $self->SUPER::foo(@_) >>, and provides a cleaner interface for it.
 
 As of version 1.00, C<Class::Method::Modifiers> is faster in some cases than
-L<Moose>. See C<benchmark/method_modifiers.pl> in the L<Moose> distribution.
+L<Moose>. See F<benchmark/method_modifiers.pl> in the L<Moose> distribution.
 
 C<Class::Method::Modifiers> also provides an additional "modifier" type,
 C<fresh>; see below.
 
 =head1 MODIFIERS
 
-=head2 before method(s) => sub { ... }
+All modifiers let you modify one or multiple methods at a time. The names of
+multiple methods can be provided as a list or as an array-reference. Examples:
+
+ before 'method' => sub { ... };
+ before 'method1', 'method2' => sub { ... };
+ before [ 'method1', 'method2' ] => sub { ... };
+
+=head2 before method(s) => sub { ... };
 
 C<before> is called before the method it is modifying. Its return value is
 totally ignored. It receives the same C<@_> as the method it is modifying
@@ -310,7 +319,7 @@ would have received. You can modify the C<@_> the original method will receive
 by changing C<$_[0]> and friends (or by changing anything inside a reference).
 This is a feature!
 
-=head2 after method(s) => sub { ... }
+=head2 after method(s) => sub { ... };
 
 C<after> is called after the method it is modifying. Its return value is
 totally ignored. It receives the same C<@_> as the method it is modifying
@@ -319,7 +328,7 @@ C<$_[0]> or references) and C<after> will see the modified version. If you
 don't like this behavior, specify both a C<before> and C<after>, and copy the
 C<@_> during C<before> for C<after> to use.
 
-=head2 around method(s) => sub { ... }
+=head2 around method(s) => sub { ... };
 
 C<around> is called instead of the method it is modifying. The method you're
 overriding is passed in as the first argument (called C<$orig> by convention).
@@ -356,6 +365,8 @@ You can use C<around> to:
 
 =head2 fresh method(s) => sub { ... };
 
+(Available since version 2.00)
+
 Unlike the other modifiers, this does not modify an existing method.
 Ordinarily, C<fresh> merely installs the coderef as a method in the
 appropriate class; but if the class hierarchy already contains a method of
@@ -363,7 +374,7 @@ the same name, an exception is thrown.  The idea of this "modifier" is to
 increase safety when subclassing.  Suppose you're writing a subclass of a
 class Some::Base, and adding a new method:
 
-    package My::SubclassOf::C;
+    package My::Subclass;
     use base 'Some::Base';
 
     sub foo { ... }
@@ -372,7 +383,7 @@ If a later version of Some::Base also adds a new method named C<foo>, your
 method will shadow that method.  Alternatively, you can use C<fresh>
 to install the additional method into your subclass:
 
-    package My::SubclassOf::C;
+    package My::Subclass;
     use base 'Some::Base';
 
     use Class::Method::Modifiers 'fresh';
@@ -403,7 +414,7 @@ function is exported only when you ask for it specifically, or for C<:all>.
 
 All three normal modifiers; C<before>, C<after>, and C<around>; are exported
 into your namespace by default. You may C<use Class::Method::Modifiers ()> to
-avoid thrashing your namespace. I may steal more features from L<Moose>, namely
+avoid modifying your namespace. I may steal more features from L<Moose>, namely
 C<super>, C<override>, C<inner>, C<augment>, and whatever the L<Moose> folks
 come up with next.
 
@@ -456,13 +467,33 @@ become more correct. And, of course, faster. :)
 
 =head1 SEE ALSO
 
+=over 4
+
+=item *
+
 L<Class::Method::Modifiers::Fast>
-L<Moose>, L<Class::Trigger>, L<Class::MOP::Method::Wrapped>, L<MRO::Compat>,
-CLOS
 
-=head1 AUTHOR
+=item *
 
-Shawn M Moore, C<sartak@gmail.com>
+L<Moose>
+
+=item *
+
+L<Class::Trigger>
+
+=item *
+
+L<Class::MOP::Method::Wrapped>
+
+=item *
+
+L<MRO::Compat>
+
+=item *
+
+L<CLOS|https://en.wikipedia.org/wiki/Common_Lisp_Object_System>
+
+=back
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -473,11 +504,64 @@ method modifiers otherwise.
 
 Thanks to Matt Trout and Stevan Little for their advice.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Class-Method-Modifiers>
+(or L<bug-Class-Method-Modifiers@rt.cpan.org|mailto:bug-Class-Method-Modifiers@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore <sartak@gmail.com>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Shawn M Moore Graham Knop Aaron Crane Peter Rabbitson David Steinbrunner gfx Justin Hunter mannih
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+Graham Knop <haarg@haarg.org>
+
+=item *
+
+Aaron Crane <arc@cpan.org>
+
+=item *
+
+Peter Rabbitson <ribasushi@cpan.org>
+
+=item *
+
+David Steinbrunner <dsteinbrunner@pobox.com>
+
+=item *
+
+gfx <gfuji@cpan.org>
+
+=item *
+
+Justin Hunter <justin.d.hunter@gmail.com>
+
+=item *
+
+mannih <github@lxxi.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 Shawn M Moore.
+This software is copyright (c) 2007 by Shawn M Moore.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
